==> CraftTweaker-common-1.18.2-9.1.213-sources.jar: com/blamejared/crafttweaker/api/action/misc/ActionSetCompostable.java <==
package com.blamejared.crafttweaker.api.action.misc;

import com.blamejared.crafttweaker.api.action.base.IUndoableAction;
import com.blamejared.crafttweaker.api.item.IItemStack;
import com.blamejared.crafttweaker.api.zencode.IScriptLoadSource;
import net.minecraft.world.level.block.ComposterBlock;

public class ActionSetCompostable implements IUndoableAction {
    
    private final IItemStack stack;
    private final float newValue;
    private final float oldValue;
    
    public ActionSetCompostable(IItemStack stack, float newValue) {
        
        this.stack = stack;
        this.newValue = newValue;
        this.oldValue = ComposterBlock.COMPOSTABLES.getOrDefault(stack.getInternal().getItem(), -1);
    }
    
    @Override
    public void apply() {
        
        if(newValue <= 0) {
            ComposterBlock.COMPOSTABLES.remove(stack.getInternal().getItem());
        } else {
            ComposterBlock.COMPOSTABLES.put(stack.getInternal().getItem(), newValue);
        }
    }
    
    @Override
    public String describe() {
        
        return "Setting Composter value of: " + stack.getCommandString() + ", to: " + newValue + ", from: " + oldValue;
    }
    
    @Override
    public void undo() {
        
        if(oldValue <= 0) {
            ComposterBlock.COMPOSTABLES.remove(stack.getInternal().getItem());
        } else {
            ComposterBlock.COMPOSTABLES.put(stack.getInternal().getItem(), oldValue);
        }
    }
    
    @Override
    public String describeUndo() {
        
        return "Undoing setting Composter value of: " + stack.getCommandString() + ", to: " + newValue + ", reverting to: " + oldValue;
    }
    
    
    @Override
    public boolean shouldApplyOn(final IScriptLoadSource source) {
        
        return true;
    }
    
}

==> CraftTweaker-common-1.21.1-21.0.27-sources.jar: com/blamejared/crafttweaker/api/action/misc/ActionSetCompostable.java <==
package com.blamejared.crafttweaker.api.action.misc;

import com.blamejared.crafttweaker.api.action.base.IUndoableAction;
import com.blamejared.crafttweaker.api.action.internal.CraftTweakerAction;
import com.blamejared.crafttweaker.api.item.IItemStack;
import com.blamejared.crafttweaker.api.zencode.IScriptLoadSource;
import com.blamejared.crafttweaker.platform.Services;
import net.minecraft.world.level.block.ComposterBlock;
import org.apache.logging.log4j.Logger;

import java.util.Optional;

public class ActionSetCompostable extends CraftTweakerAction implements IUndoableAction {
    
    private final IItemStack stack;
    private final float newValue;
    private final float oldValue;
    
    public ActionSetCompostable(IItemStack stack, float newValue) {
        
        this.stack = stack;
        this.newValue = newValue;
        this.oldValue = ComposterBlock.COMPOSTABLES.getOrDefault(stack.getInternal().getItem(), -1);
    }
    
    @Override
    public void apply() {
        
        Services.PLATFORM.setCompostable(stack, Optional.of(newValue).filter(aFloat -> aFloat > 0), false);
    }
    
    @Override
    public String describe() {
        
        return "Setting Composter value of: " + stack.getCommandString() + ", to: " + newValue + ", from: " + oldValue;
    }
    
    @Override
    public void undo() {
        
        Services.PLATFORM.setCompostable(stack, Optional.of(oldValue).filter(aFloat -> aFloat > 0), true);
    }
    
    @Override
    public String describeUndo() {
        
        return "Undoing setting Composter value of: " + stack.getCommandString() + ", to: " + newValue + ", reverting to: " + oldValue;
    }
    
    @Override
    public boolean shouldApplyOn(final IScriptLoadSource source, final Logger logger) {
        
        return true;
    }
    
}
